DesignSystemShapes class

Constructors

DesignSystemShapes({required double cornerNone, required double cornerSmall, required double cornerMedium, required double cornerLarge, required double cornerRound})
const
DesignSystemShapes.fromTokens(BrandTokens tokens)
factory

Properties

cornerLarge double
final
cornerMedium double
final
cornerNone double
final
cornerRound double
final
cornerSmall double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited