DesignSystemTypography class

Constructors

DesignSystemTypography({required TextStyle display, required TextStyle headline, required TextStyle title, required TextStyle body, required TextStyle label, required TextStyle button, required TextStyle caption})
const
DesignSystemTypography.fromTokens(BrandTokens tokens)
factory

Properties

body TextStyle
final
button TextStyle
final
caption TextStyle
final
display TextStyle
final
hashCode int
The hash code for this object.
no setterinherited
headline TextStyle
final
label TextStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited