DesignSystemTheme class
Constructors
- DesignSystemTheme({required DesignSystemColors colors, required DesignSystemTypography typography, required DesignSystemSpacing spacing, required DesignSystemShapes shapes, required BrandTokens tokens})
-
const
- DesignSystemTheme.fromBrandTokens(BrandTokens tokens)
-
factory
Properties
- colors → DesignSystemColors
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapes → DesignSystemShapes
-
final
- spacing → DesignSystemSpacing
-
final
- tokens → BrandTokens
-
final
- typography → DesignSystemTypography
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited